
History
=======

1.3
---

- Adopt resource providing
  [rnix, 2012-06-12]

- Provide example widget
  [rnix, 2012-06-12]

1.2
---

- fixed resources
  [rnix, 2012-03-01]

- added entry point base registration
  [agitator, 2012-02-15]

- add display mode css class
  [rnix, 2011-12-18]

1.1
---

- adopt to yafowil 1.2
  [jensens, 2011-09-20]

- make ready for z2c.autoinclude+Plone (only if available).
  [jensens, 2011-09-20]

1.0
---

- add display renderer
  [rnix, 2011-08-03]

- adopt to yafowil 1.1
  [rnix, 2011-07-08]

0.9.1
-----

- test coverage
  [rnix, 2011-05-07]

0.9
---

- made it work [rnix]
